==> istio-model-v1beta1-6.2.0-sources.jar: io/fabric8/istio/api/networking/v1beta1/VirtualServiceFluentImpl.java <==
package io.fabric8.istio.api.networking.v1beta1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.istio.api.meta.v1alpha1.IstioStatusFluentImpl;
import io.fabric8.istio.api.meta.v1alpha1.IstioStatusBuilder;
import io.fabric8.kubernetes.api.model.ObjectMetaFluentImpl;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import io.fabric8.istio.api.meta.v1alpha1.IstioStatus;
import java.lang.Object;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class VirtualServiceFluentImpl<A extends VirtualServiceFluent<A>> extends BaseFluent<A> implements VirtualServiceFluent<A>{
  public VirtualServiceFluentImpl() {
  }
  public VirtualServiceFluentImpl(VirtualService instance) {
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withSpec(instance.getSpec()); 
    this.withStatus(instance.getStatus()); 
  }
  private String apiVersion;
  private String kind;
  private ObjectMetaBuilder metadata;
  private VirtualServiceSpecBuilder spec;
  private IstioStatusBuilder status;
  public String getApiVersion() {
    return this.apiVersion;
  }
  public A withApiVersion(String apiVersion) {
    this.apiVersion=apiVersion; return (A) this;
  }
  public Boolean hasApiVersion() {
    return this.apiVersion != null;
  }
  public String getKind() {
    return this.kind;
  }
  public A withKind(String kind) {
    this.kind=kind; return (A) this;
  }
  public Boolean hasKind() {
    return this.kind != null;
  }
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectMeta getMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public ObjectMeta buildMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public A withMetadata(ObjectMeta metadata) {
    _visitables.get("metadata").remove(this.metadata);
    if (metadata!=null){ this.metadata= new ObjectMetaBuilder(metadata); _visitables.get("metadata").add(this.metadata);} else { this.metadata = null; _visitables.get("metadata").remove(this.metadata); } return (A) this;
  }
  public Boolean hasMetadata() {
    return this.metadata != null;
  }
  public VirtualServiceFluent.MetadataNested<A> withNewMetadata() {
    return new VirtualServiceFluentImpl.MetadataNestedImpl();
  }
  public VirtualServiceFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item) {
    return new VirtualServiceFluentImpl.MetadataNestedImpl(item);
  }
  public VirtualServiceFluent.MetadataNested<A> editMetadata() {
    return withNewMetadataLike(getMetadata());
  }
  public VirtualServiceFluent.MetadataNested<A> editOrNewMetadata() {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): new ObjectMetaBuilder().build());
  }
  public VirtualServiceFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item) {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildSpec instead.
   * @return The buildable object.
   */
  @Deprecated
  public VirtualServiceSpec getSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public VirtualServiceSpec buildSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public A withSpec(VirtualServiceSpec spec) {
    _visitables.get("spec").remove(this.spec);
    if (spec!=null){ this.spec= new VirtualServiceSpecBuilder(spec); _visitables.get("spec").add(this.spec);} else { this.spec = null; _visitables.get("spec").remove(this.spec); } return (A) this;
  }
  public Boolean hasSpec() {
    return this.spec != null;
  }
  public VirtualServiceFluent.SpecNested<A> withNewSpec() {
    return new VirtualServiceFluentImpl.SpecNestedImpl();
  }
  public VirtualServiceFluent.SpecNested<A> withNewSpecLike(VirtualServiceSpec item) {
    return new VirtualServiceFluentImpl.SpecNestedImpl(item);
  }
  public VirtualServiceFluent.SpecNested<A> editSpec() {
    return withNewSpecLike(getSpec());
  }
  public VirtualServiceFluent.SpecNested<A> editOrNewSpec() {
    return withNewSpecLike(getSpec() != null ? getSpec(): new VirtualServiceSpecBuilder().build());
  }
  public VirtualServiceFluent.SpecNested<A> editOrNewSpecLike(VirtualServiceSpec item) {
    return withNewSpecLike(getSpec() != null ? getSpec(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildStatus instead.
   * @return The buildable object.
   */
  @Deprecated
  public IstioStatus getStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public IstioStatus buildStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public A withStatus(IstioStatus status) {
    _visitables.get("status").remove(this.status);
    if (status!=null){ this.status= new IstioStatusBuilder(status); _visitables.get("status").add(this.status);} else { this.status = null; _visitables.get("status").remove(this.status); } return (A) this;
  }
  public Boolean hasStatus() {
    return this.status != null;
  }
  public VirtualServiceFluent.StatusNested<A> withNewStatus() {
    return new VirtualServiceFluentImpl.StatusNestedImpl();
  }
  public VirtualServiceFluent.StatusNested<A> withNewStatusLike(IstioStatus item) {
    return new VirtualServiceFluentImpl.StatusNestedImpl(item);
  }
  public VirtualServiceFluent.StatusNested<A> editStatus() {
    return withNewStatusLike(getStatus());
  }
  public VirtualServiceFluent.StatusNested<A> editOrNewStatus() {
    return withNewStatusLike(getStatus() != null ? getStatus(): new IstioStatusBuilder().build());
  }
  public VirtualServiceFluent.StatusNested<A> editOrNewStatusLike(IstioStatus item) {
    return withNewStatusLike(getStatus() != null ? getStatus(): item);
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    VirtualServiceFluentImpl that = (VirtualServiceFluentImpl) o;
    if (apiVersion != null ? !apiVersion.equals(that.apiVersion) :that.apiVersion != null) return false;
    if (kind != null ? !kind.equals(that.kind) :that.kind != null) return false;
    if (metadata != null ? !metadata.equals(that.metadata) :that.metadata != null) return false;
    if (spec != null ? !spec.equals(that.spec) :that.spec != null) return false;
    if (status != null ? !status.equals(that.status) :that.status != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(apiVersion,  kind,  metadata,  spec,  status,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (apiVersion != null) { sb.append("apiVersion:"); sb.append(apiVersion + ","); }
    if (kind != null) { sb.append("kind:"); sb.append(kind + ","); }
    if (metadata != null) { sb.append("metadata:"); sb.append(metadata + ","); }
    if (spec != null) { sb.append("spec:"); sb.append(spec + ","); }
    if (status != null) { sb.append("status:"); sb.append(status); }
    sb.append("}");
    return sb.toString();
  }
  class MetadataNestedImpl<N> extends ObjectMetaFluentImpl<VirtualServiceFluent.MetadataNested<N>> implements VirtualServiceFluent.MetadataNested<N>,Nested<N>{
    MetadataNestedImpl(ObjectMeta item) {
      this.builder = new ObjectMetaBuilder(this, item);
    }
    MetadataNestedImpl() {
      this.builder = new ObjectMetaBuilder(this);
    }
    ObjectMetaBuilder builder;
    public N and() {
      return (N) VirtualServiceFluentImpl.this.withMetadata(builder.build());
    }
    public N endMetadata() {
      return and();
    }
    
  }
  class SpecNestedImpl<N> extends VirtualServiceSpecFluentImpl<VirtualServiceFluent.SpecNested<N>> implements VirtualServiceFluent.SpecNested<N>,Nested<N>{
    SpecNestedImpl(VirtualServiceSpec item) {
      this.builder = new VirtualServiceSpecBuilder(this, item);
    }
    SpecNestedImpl() {
      this.builder = new VirtualServiceSpecBuilder(this);
    }
    VirtualServiceSpecBuilder builder;
    public N and() {
      return (N) VirtualServiceFluentImpl.this.withSpec(builder.build());
    }
    public N endSpec() {
      return and();
    }
    
  }
  class StatusNestedImpl<N> extends IstioStatusFluentImpl<VirtualServiceFluent.StatusNested<N>> implements VirtualServiceFluent.StatusNested<N>,Nested<N>{
    StatusNestedImpl(IstioStatus item) {
      this.builder = new IstioStatusBuilder(this, item);
    }
    StatusNestedImpl() {
      this.builder = new IstioStatusBuilder(this);
    }
    IstioStatusBuilder builder;
    public N and() {
      return (N) VirtualServiceFluentImpl.this.withStatus(builder.build());
    }
    public N endStatus() {
      return and();
    }
    
  }
  
}

==> istio-model-v1beta1-6.6.1-sources.jar: io/fabric8/istio/api/networking/v1beta1/VirtualServiceFluentImpl.java <==
package io.fabric8.istio.api.networking.v1beta1;

import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.model.ObjectMetaFluentImpl;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.istio.api.meta.v1alpha1.IstioStatus;
import java.lang.Object;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class VirtualServiceFluentImpl<A extends VirtualServiceFluent<A>> extends BaseFluent<A> implements VirtualServiceFluent<A>{
  public VirtualServiceFluentImpl() {
  }
  public VirtualServiceFluentImpl(VirtualService instance) {
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withSpec(instance.getSpec()); 
    this.withStatus(instance.getStatus()); 
  }
  private String apiVersion;
  private String kind;
  private ObjectMetaBuilder metadata;
  private VirtualServiceSpecBuilder spec;
  private IstioStatus status;
  public String getApiVersion() {
    return this.apiVersion;
  }
  public A withApiVersion(String apiVersion) {
    this.apiVersion=apiVersion; return (A) this;
  }
  public Boolean hasApiVersion() {
    return this.apiVersion != null;
  }
  public String getKind() {
    return this.kind;
  }
  public A withKind(String kind) {
    this.kind=kind; return (A) this;
  }
  public Boolean hasKind() {
    return this.kind != null;
  }
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectMeta getMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public ObjectMeta buildMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public A withMetadata(ObjectMeta metadata) {
    _visitables.get("metadata").remove(this.metadata);
    if (metadata!=null){ this.metadata= new ObjectMetaBuilder(metadata); _visitables.get("metadata").add(this.metadata);} else { this.metadata = null; _visitables.get("metadata").remove(this.metadata); } return (A) this;
  }
  public Boolean hasMetadata() {
    return this.metadata != null;
  }
  public VirtualServiceFluent.MetadataNested<A> withNewMetadata() {
    return new VirtualServiceFluentImpl.MetadataNestedImpl();
  }
  public VirtualServiceFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item) {
    return new VirtualServiceFluentImpl.MetadataNestedImpl(item);
  }
  public VirtualServiceFluent.MetadataNested<A> editMetadata() {
    return withNewMetadataLike(getMetadata());
  }
  public VirtualServiceFluent.MetadataNested<A> editOrNewMetadata() {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): new ObjectMetaBuilder().build());
  }
  public VirtualServiceFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item) {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildSpec instead.
   * @return The buildable object.
   */
  @Deprecated
  public VirtualServiceSpec getSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public VirtualServiceSpec buildSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public A withSpec(VirtualServiceSpec spec) {
    _visitables.get("spec").remove(this.spec);
    if (spec!=null){ this.spec= new VirtualServiceSpecBuilder(spec); _visitables.get("spec").add(this.spec);} else { this.spec = null; _visitables.get("spec").remove(this.spec); } return (A) this;
  }
  public Boolean hasSpec() {
    return this.spec != null;
  }
  public VirtualServiceFluent.SpecNested<A> withNewSpec() {
    return new VirtualServiceFluentImpl.SpecNestedImpl();
  }
  public VirtualServiceFluent.SpecNested<A> withNewSpecLike(VirtualServiceSpec item) {
    return new VirtualServiceFluentImpl.SpecNestedImpl(item);
  }
  public VirtualServiceFluent.SpecNested<A> editSpec() {
    return withNewSpecLike(getSpec());
  }
  public VirtualServiceFluent.SpecNested<A> editOrNewSpec() {
    return withNewSpecLike(getSpec() != null ? getSpec(): new VirtualServiceSpecBuilder().build());
  }
  public VirtualServiceFluent.SpecNested<A> editOrNewSpecLike(VirtualServiceSpec item) {
    return withNewSpecLike(getSpec() != null ? getSpec(): item);
  }
  public IstioStatus getStatus() {
    return this.status;
  }
  public A withStatus(IstioStatus status) {
    this.status=status; return (A) this;
  }
  public Boolean hasStatus() {
    return this.status != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    VirtualServiceFluentImpl that = (VirtualServiceFluentImpl) o;
    if (apiVersion != null ? !apiVersion.equals(that.apiVersion) :that.apiVersion != null) return false;
    if (kind != null ? !kind.equals(that.kind) :that.kind != null) return false;
    if (metadata != null ? !metadata.equals(that.metadata) :that.metadata != null) return false;
    if (spec != null ? !spec.equals(that.spec) :that.spec != null) return false;
    if (status != null ? !status.equals(that.status) :that.status != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(apiVersion,  kind,  metadata,  spec,  status,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (apiVersion != null) { sb.append("apiVersion:"); sb.append(apiVersion + ","); }
    if (kind != null) { sb.append("kind:"); sb.append(kind + ","); }
    if (metadata != null) { sb.append("metadata:"); sb.append(metadata + ","); }
    if (spec != null) { sb.append("spec:"); sb.append(spec + ","); }
    if (status != null) { sb.append("status:"); sb.append(status); }
    sb.append("}");
    return sb.toString();
  }
  class MetadataNestedImpl<N> extends ObjectMetaFluentImpl<VirtualServiceFluent.MetadataNested<N>> implements VirtualServiceFluent.MetadataNested<N>,Nested<N>{
    MetadataNestedImpl(ObjectMeta item) {
      this.builder = new ObjectMetaBuilder(this, item);
    }
    MetadataNestedImpl() {
      this.builder = new ObjectMetaBuilder(this);
    }
    ObjectMetaBuilder builder;
    public N and() {
      return (N) VirtualServiceFluentImpl.this.withMetadata(builder.build());
    }
    public N endMetadata() {
      return and();
    }
    
  }
  class SpecNestedImpl<N> extends VirtualServiceSpecFluentImpl<VirtualServiceFluent.SpecNested<N>> implements VirtualServiceFluent.SpecNested<N>,Nested<N>{
    SpecNestedImpl(VirtualServiceSpec item) {
      this.builder = new VirtualServiceSpecBuilder(this, item);
    }
    SpecNestedImpl() {
      this.builder = new VirtualServiceSpecBuilder(this);
    }
    VirtualServiceSpecBuilder builder;
    public N and() {
      return (N) VirtualServiceFluentImpl.this.withSpec(builder.build());
    }
    public N endSpec() {
      return and();
    }
    
  }
  
}
